#
# spec file for package bootcycle
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           bootcycle
Version:        0.3
Release:        4.1
Summary:        Boot Cycle Detection
License:        GPL-2.0+
Group:          System/Boot
%if 0%{?suse_version} >= 1315
BuildRequires:  grub2
BuildRequires:  systemd-rpm-macros
PreReq:         %fillup_prereq
PreReq:         grub2
%{?systemd_requires}
%else
PreReq:         %fillup_prereq %insserv_prereq
%ifarch %ix86 x86_64
Requires:       grub
%endif
%ifarch %ia64
Requires:       efibootmgr
%endif
%endif
Source0:        sysconfig.bootloader-bootcycle
Source1:        boot.cycle.IA32
Source3:        boot.cycle.IA64
Source2:        README.IA32
Source4:        README.IA64
Source5:        boot.cycle.grub2
Source6:        bootcycle.service
Source7:        grub_menuentry_halt
Source8:        README.grub2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} >= 1315
BuildArch:      noarch
%else
ExclusiveArch:  %ix86 ia64 x86_64
%endif

%description
This package provides a boot script that is used for boot cycle
detection to avoid unconditional reboot cycles on an unsupervised
system.  For example, on INTEL IA32 the GNU GRUB multiboot loader is
used for this.

%prep
%setup -n %{name}-%{version} -c -T
%if 0%{?suse_version} >= 1315
    cp %{SOURCE8} README
%else
%ifarch %ix86 x86_64
    cp %{SOURCE1} boot.cycle
    cp %{SOURCE2} README
%endif
%ifarch ia64
    cp %{SOURCE3} boot.cycle
    cp %{SOURCE4} README
%endif
%endif

%install
    install -d -m 0755 $RPM_BUILD_ROOT/var/adm/fillup-templates
    install -c -m 0644 %{SOURCE0} $RPM_BUILD_ROOT/var/adm/fillup-templates/
%if 0%{?suse_version} >= 1315
    install -D -m 0755 %{SOURCE5} $RPM_BUILD_ROOT/%{_sbindir}/bootcycle
    install -D -m 444 %{SOURCE6} $RPM_BUILD_ROOT/%{_unitdir}/bootcycle.service
    install -D -m 0755 %{SOURCE7} $RPM_BUILD_ROOT/%{_sysconfdir}/grub.d/50_bootcycle
%else
    install -d -m 0755 $RPM_BUILD_ROOT/etc/init.d/boot.d
    install -c -m 0755 boot.cycle $RPM_BUILD_ROOT/etc/init.d/
%endif

%pre
%if 0%{?suse_version} >= 1315
%service_add_pre bootcycle.service
%endif

%post
%{fillup_only -an bootloader}
%if 0%{?suse_version} >= 1315
%service_add_post bootcycle.service
/usr/sbin/grub2-mkconfig -o /boot/grub2/grub.cfg || :
%else
%{fillup_and_insserv -fY boot.cycle}
%endif

%preun
%if 0%{?suse_version} >= 1315
%service_del_preun bootcycle.service
%endif

%postun
%if 0%{?suse_version} >= 1315
%service_del_postun bootcycle.service
%else
%{insserv_cleanup}
%endif

%files
%defattr(-,root,root)
/var/adm/fillup-templates/*
%doc README
%if 0%{?suse_version} >= 1315
%{_sbindir}/bootcycle
%{_unitdir}/bootcycle.service
%config %{_sysconfdir}/grub.d/50_bootcycle
%else
%config /etc/init.d/boot.cycle
%endif

%changelog
* Tue May 17 2016 mchang@suse.com
- Fix halt menuentry syntax error in pygrub (bsc#978413)
  * modified grub_menuentry_halt
* Thu May 28 2015 mchang@suse.com
- Re-Introduce boot cycle functionality for Grub2 (fate#316968)
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Thu Aug 26 2010 gber@opensuse.org
- make boot.cycle exit gracefully if /usr is on NFS
* Fri Aug 22 2008 ro@suse.de
- remove deprecated options from fillup_and_insserv
* Wed Aug 13 2008 ro@suse.de
- add exlusivearch
* Wed Jul 30 2008 werner@suse.de
- Make boot scripts know about new upcoming startpar and insserv
* Fri Feb 22 2008 werner@suse.de
- Clean up boot service link durinf uninstall (bnc#362920)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Fri Feb 20 2004 ro@suse.de
- do noting for stop case of boot.cycle script
* Sun Nov 23 2003 ro@suse.de
- remove directories already part of filesystem.rpm
* Fri Aug  8 2003 kukuk@suse.de
- Fix for AMD64
* Tue Jul 15 2003 werner@suse.de
- Add README for IA64 (bug #27609)
* Fri Jun 20 2003 schwab@suse.de
- Add support for ia64.
* Fri Mar 14 2003 werner@suse.de
- Fix path of grub installer (bug #25352)
- Move option from shell to command line of installer (bug #25358)
- Fix and add more comments to the README file (bug #25359)
* Wed Mar  5 2003 werner@suse.de
- Initial package for boot cycle detection
